AppState class

Inheritance

Constructors

AppState()

Properties

alreadyAdded ↔ List<int>
getter/setter pair
animationComplete ↔ bool
getter/setter pair
animationEnd ↔ bool
getter/setter pair
currentPage ↔ int
getter/setter pair
currentPageComplete ↔ int
getter/setter pair
currentTotalPages → int
no setter
document ↔ PdfDocument?
Getters
getter/setter pair
errorMessage ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isAnimationReady ↔ bool
getter/setter pair
isLoading ↔ bool
getter/setter pair
isMobile → bool
Platform detection
no setter
isMobileZoomAnimation ↔ bool
getter/setter pair
isMobileZoomed ↔ bool
getter/setter pair
isSwipeInProgress ↔ bool
getter/setter pair
isSwipingLeft ↔ bool
getter/setter pair
isZoomed ↔ bool
getter/setter pair
pageImages ↔ List<PdfPageImage>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldShowLeftPage → bool
Computed boolean for left page visibility
no setter
showLastPage ↔ bool
getter/setter pair
totalPages ← int
no getter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clear() → void
Clear all state
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
resetMobileZoom() → void
toggleMobileZoom() → void
Mobile zoom control methods
toString() → String
A string representation of this object.
inherited
updateMultiple({bool? animationEnd, bool? animationComplete, bool? isAnimationReady, bool? isSwipeInProgress, bool? isSwipingLeft, int? currentPage, int? currentPageComplete}) → void
Batch update method for multiple state changes

Operators

operator ==(Object other) → bool
The equality operator.
inherited