BookAnimationController class

Constructors

BookAnimationController({required AppState appState, required PdfLoader pdfLoader, required TickerProvider vsync})

Properties

animationController → AnimationController
no setter
appState → AppState
final
hashCode → int
The hash code for this object.
no setterinherited
pdfLoader → PdfLoader
final
rotationAnimation → Animation<double>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canNavigate(bool swipeLeft) → bool
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
triggerFlip(bool swipeLeft) → Future<void>
Handles page flipping animation with smart interruption for fast navigation

Operators

operator ==(Object other) → bool
The equality operator.
inherited