PageNavigation class

Constructors

Properties

animationController → BookAnimationController
final
appState → AppState
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canNavigate(bool swipeLeft) → bool
Checks if navigation is possible in the given direction
handleHorizontalDrag(DragUpdateDetails details) → void
Handles horizontal drag gestures for page navigation
Navigates to the next page with error handling
Navigates to the previous page with error handling
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited