PdfBookViewerStyle class

Styling options for the PDF book viewer

Constructors

PdfBookViewerStyle({Color? backgroundColor, Color? bookBackgroundColor, Color? centerDividerColor, double centerDividerWidth = 5.0, Color? loadingIndicatorColor, BoxDecoration? bookContainerDecoration, NavigationControlsStyle? navigationControlsStyle})
const

Properties

backgroundColor → Color?
final
bookBackgroundColor → Color?
final
bookContainerDecoration → BoxDecoration?
final
centerDividerColor → Color?
final
centerDividerWidth → double
final
hashCode → int
The hash code for this object.
no setterinherited
loadingIndicatorColor → Color?
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

defaultStyle() → PdfBookViewerStyle